#!/bin/bash

set -e
set -u

function makeScriptdir {
	basedir="${1}"
	foldername="${2}"
	
	mkdir -p "${basedir}/${foldername}"
	cat > "${basedir}/${foldername}/_dir.json" <<EOF
{
  "common": {
    "name": "${foldername}"
  },
  "type": "channel",
  "_id": "script.js.${foldername}",
  "acl": {
    "object": 1636,
    "owner": "system.user.admin",
    "ownerGroup": "system.group.administrator"
  }
}
EOF

truncate -s -1 "${basedir}/${foldername}/_dir.json"
}

function copyScriptfile {
	basedir="${1}"
	sourcefile="${2}"
	cat > "${basedir}/${sourcefile}on" <<EOF
/* -- do not edit following lines - START --
{
  "debug": false,
  "verbose": false
}
-- do not edit previous lines - END --*/
// jshint maxerr:10000
EOF
cat "${sourcefile}" >> "${basedir}/${sourcefile}on"
} 
	


# go to local directory
pushd "$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )" > /dev/null

# create temp dir
TMPDIR="$(mktemp -d)"

# create resuired target folders
for dir in global common; do
	makeScriptdir "${TMPDIR}" "${dir}"
done

# copy all scripts as needed
find . -maxdepth 1 -name \*.js -type f | while read f; do
	copyScriptfile "${TMPDIR}" "$(echo "${f}" | cut -c3-)"
done

# compile helpers.json
cat > "${TMPDIR}/global/helpers.json" <<EOF
/* -- do not edit following lines - START --
{
  "debug": false,
  "verbose": false
}
-- do not edit previous lines - END --*/
// jshint maxerr:10000
EOF
echo "// compiled helpers" >> "${TMPDIR}/global/helpers.json"
echo "" >> "${TMPDIR}/global/helpers.json"  
cat "global/index.txt" | while read l; do
	echo "// --- start of snippet included from ${l}.js ---" >> "${TMPDIR}/global/helpers.json"
	cat "global/${l}.js" >> "${TMPDIR}/global/helpers.json"
	echo "" >> "${TMPDIR}/global/helpers.json" 
	echo "// --- end of snippet included from ${l}.js ---" >> "${TMPDIR}/global/helpers.json"
done

#find "${TMPDIR}"
#cat "${TMPDIR}/mqtt_raidstate.json"

pushd "${TMPDIR}" > /dev/null
zip -r scripts *
popd > /dev/null

mv "${TMPDIR}/scripts.zip" ./

rm -rf "${TMPDIR}"

popd > /dev/null